#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.3.0.0-K7RovhvWUDq6glVn3GmvOD
key:                  hls-call-hierarchy-plugin-2.3.0.0-K7RovhvWUDq6glVn3GmvOD
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  a61bb9617a8778308de01a9f5c05fdbf
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.3.0.0-K7RovhvWUDq6glVn3GmvOD
depends:
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I base-4.18.2.1 containers-0.6.7
    extra-1.7.16-COAoMleqge7G93j2zK3Os3
    ghcide-2.3.0.0-9MX9KkPiOWIFpwMz4KO57
    hiedb-0.4.3.0-Fwuou394YkhHgRNX5gRWe7
    hls-plugin-api-2.3.0.0-IQT22PBObv23WRuowMhdPw
    lens-5.3.4-AArhojR1bHQDPd0CW0dSET
    lsp-2.2.0.0-DVNEHy3LCCE9iC1Qc3jNOD
    sqlite-simple-0.4.19.0-4lfN9MLoGcgKpl6bJV4Tf8 text-2.0.2
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

